==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/mgh-MZ.pl <==
{
  am_pm_abbreviated => [
    "wichishu",
    "mchochil\N{U+2019}l",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "y MMMM",
    yMMMd => "MMM d, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mgh-MZ",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Ara",
    "Iju",
    "Jmo",
    "Sab",
  ],
  day_format_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "S",
  ],
  day_format_wide => [
    "Jumatatu",
    "Jumanne",
    "Jumatano",
    "Arahamisi",
    "Ijumaa",
    "Jumamosi",
    "Sabato",
  ],
  day_stand_alone_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Ara",
    "Iju",
    "Jmo",
    "Sab",
  ],
  day_stand_alone_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "S",
  ],
  day_stand_alone_wide => [
    "Jumatatu",
    "Jumanne",
    "Jumatano",
    "Arahamisi",
    "Ijumaa",
    "Jumamosi",
    "Sabato",
  ],
  era_abbreviated => [
    "HY",
    "YY",
  ],
  era_narrow => [
    "HY",
    "YY",
  ],
  era_wide => [
    "Hinapiya yesu",
    "Yopia yesu",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Makhuwa-Meetto",
  month_format_abbreviated => [
    "Kwa",
    "Una",
    "Rar",
    "Che",
    "Tha",
    "Moc",
    "Sab",
    "Nan",
    "Tis",
    "Kum",
    "Moj",
    "Yel",
  ],
  month_format_narrow => [
    "K",
    "U",
    "R",
    "C",
    "T",
    "M",
    "S",
    "N",
    "T",
    "K",
    "M",
    "Y",
  ],
  month_format_wide => [
    "Mweri wo kwanza",
    "Mweri wo unayeli",
    "Mweri wo uneraru",
    "Mweri wo unecheshe",
    "Mweri wo unethanu",
    "Mweri wo thanu na mocha",
    "Mweri wo saba",
    "Mweri wo nane",
    "Mweri wo tisa",
    "Mweri wo kumi",
    "Mweri wo kumi na moja",
    "Mweri wo kumi na yel\N{U+2019}li",
  ],
  month_stand_alone_abbreviated => [
    "Kwa",
    "Una",
    "Rar",
    "Che",
    "Tha",
    "Moc",
    "Sab",
    "Nan",
    "Tis",
    "Kum",
    "Moj",
    "Yel",
  ],
  month_stand_alone_narrow => [
    "K",
    "U",
    "R",
    "C",
    "T",
    "M",
    "S",
    "N",
    "T",
    "K",
    "M",
    "Y",
  ],
  month_stand_alone_wide => [
    "Mweri wo kwanza",
    "Mweri wo unayeli",
    "Mweri wo uneraru",
    "Mweri wo unecheshe",
    "Mweri wo unethanu",
    "Mweri wo thanu na mocha",
    "Mweri wo saba",
    "Mweri wo nane",
    "Mweri wo tisa",
    "Mweri wo kumi",
    "Mweri wo kumi na moja",
    "Mweri wo kumi na yel\N{U+2019}li",
  ],
  name => "Makhuwa-Meetto Mozambique",
  native_language => "Makua",
  native_name => "Makua Umozambiki",
  native_script => undef,
  native_territory => "Umozambiki",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Mozambique",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/mgh-MZ.pl <==
{
  am_pm_abbreviated => [
    "wichishu",
    "mchochil\N{U+2019}l",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "y MMMM",
    yMMMd => "MMM d, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mgh-MZ",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Ara",
    "Iju",
    "Jmo",
    "Sab",
  ],
  day_format_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "S",
  ],
  day_format_wide => [
    "Jumatatu",
    "Jumanne",
    "Jumatano",
    "Arahamisi",
    "Ijumaa",
    "Jumamosi",
    "Sabato",
  ],
  day_stand_alone_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Ara",
    "Iju",
    "Jmo",
    "Sab",
  ],
  day_stand_alone_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "S",
  ],
  day_stand_alone_wide => [
    "Jumatatu",
    "Jumanne",
    "Jumatano",
    "Arahamisi",
    "Ijumaa",
    "Jumamosi",
    "Sabato",
  ],
  era_abbreviated => [
    "HY",
    "YY",
  ],
  era_narrow => [
    "HY",
    "YY",
  ],
  era_wide => [
    "Hinapiya yesu",
    "Yopia yesu",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Makhuwa-Meetto",
  month_format_abbreviated => [
    "Kwa",
    "Una",
    "Rar",
    "Che",
    "Tha",
    "Moc",
    "Sab",
    "Nan",
    "Tis",
    "Kum",
    "Moj",
    "Yel",
  ],
  month_format_narrow => [
    "K",
    "U",
    "R",
    "C",
    "T",
    "M",
    "S",
    "N",
    "T",
    "K",
    "M",
    "Y",
  ],
  month_format_wide => [
    "Mweri wo kwanza",
    "Mweri wo unayeli",
    "Mweri wo uneraru",
    "Mweri wo unecheshe",
    "Mweri wo unethanu",
    "Mweri wo thanu na mocha",
    "Mweri wo saba",
    "Mweri wo nane",
    "Mweri wo tisa",
    "Mweri wo kumi",
    "Mweri wo kumi na moja",
    "Mweri wo kumi na yel\N{U+2019}li",
  ],
  month_stand_alone_abbreviated => [
    "Kwa",
    "Una",
    "Rar",
    "Che",
    "Tha",
    "Moc",
    "Sab",
    "Nan",
    "Tis",
    "Kum",
    "Moj",
    "Yel",
  ],
  month_stand_alone_narrow => [
    "K",
    "U",
    "R",
    "C",
    "T",
    "M",
    "S",
    "N",
    "T",
    "K",
    "M",
    "Y",
  ],
  month_stand_alone_wide => [
    "Mweri wo kwanza",
    "Mweri wo unayeli",
    "Mweri wo uneraru",
    "Mweri wo unecheshe",
    "Mweri wo unethanu",
    "Mweri wo thanu na mocha",
    "Mweri wo saba",
    "Mweri wo nane",
    "Mweri wo tisa",
    "Mweri wo kumi",
    "Mweri wo kumi na moja",
    "Mweri wo kumi na yel\N{U+2019}li",
  ],
  name => "Makhuwa-Meetto Mozambique",
  native_language => "Makua",
  native_name => "Makua Umozambiki",
  native_script => undef,
  native_territory => "Umozambiki",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Mozambique",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
